@@ -154,8 +154,6 @@ void display(int srow, int scol)
 		printf("=");
 
 	printf("\n");			
-	printf("x hjkl m");
-	printf("\n");			
 
 	return;
 }
@@ -342,6 +340,7 @@ void stat(int mam)
 	}
 
 //	printf("Status -- %i/%i -- %.2f -- %i -- %s -- %s -- %s --\n", roughness, grid_size, world_size, VER, __DATE__, __TIME__, smam);
+	printf("Status -- %i -- %s -- %s -- %s --\n", VER, __DATE__, __TIME__, smam);
 
 	printf("race	pop	age	food	gen	size	attack	defend	fov\n");
 	printf("all	%i	%i	%i	%i	%i	%i	%i	%i\n", races[0].pop, races[0].age[AVG], races[0].food[AVG], races[0].gen[AVG], races[0].size[AVG], races[0].attack[AVG], races[0].defend[AVG], races[0].fov[AVG]);
