@@ -1,5 +1,5 @@
 /*
- * Copyright James Morse Y2K +1, +2, +3, +8
+ * Copyright James Morse Y2K+1
  * This is GPLed software 
  * please read COPYING
  *
@@ -12,9 +12,10 @@
 void gnu(void)
 {
         printf("************************************************************************\n");
-        printf("* Copyright (C) Y2K +1, +2, +3, +8 James Morse                         *\n");
-        printf("* please read COPYING                                                  *\n");
-        printf("* Questions and comments may be sent to: xbeastx@freeshell.org         *\n");
+        printf("*                                                                      *\n");
+        printf("* Copyright (C) Y2K+1 James Morse   please read COPYING                *\n");
+        printf("*                                                                      *\n");
+        printf("* Questions and comments may be sent to: xbeastx@writeme.com           *\n");
         printf("*                                                                      *\n");
         printf("* This program is free software; you can redistribute it and/or modify *\n");
         printf("* it under the terms of the GNU General Public License as published by *\n");
@@ -32,7 +33,7 @@ void gnu(void)
         printf("* Free Software Foundation, Inc.                                       *\n");
         printf("* 59 Temple Place, Suite 330                                           *\n");
         printf("* Boston, MA  02111-1307  USA                                          *\n");
+        printf("*                                                                      *\n");
         printf("************************************************************************\n");
         return;
 }
-
